@@ -4,18 +4,11 @@ import hashlib
 import filesystem_query
 import esgf_query
 
-import valid_experiments_path
-import valid_experiments_time
-
 import copy
 
 import remote_archive
 
 #import database_utils
-import io_tools
-
-import tree_utils
-from tree_utils import File_Expt
 
 import cdb_query_archive_parsers
 import cdb_query_archive_class
@@ -42,8 +35,8 @@ def main(project):
     2. the ESGF {0} archive.
 
     '''.format(project))
-    epilog='Frederic Laliberte, Paul Kushner 02/2014'
-    version_num='0.9'
+    epilog='Frederic Laliberte, Paul Kushner 06/2014'
+    version_num='1.0.0'
     parser = argparse.ArgumentParser(formatter_class=argparse.RawDescriptionHelpFormatter,
                             description=description,
                             version='%(prog)s '+version_num,
@@ -56,27 +49,33 @@ def main(project):
 
     options=parser.parse_args()
 
+    if 'related_experiments' in dir(options) and not options.related_experiments:
+        project_drs.simulations_desc.append('experiment')
+
     #Slicing time is peculiar
     for time_opt in ['year','month']:
         if time_opt in dir(options) and getattr(options,time_opt):
             options.time=True
 
     #Load pointer file:
-    if options.command=='remote_retrieve':
-        netcdf_utils.retrieve_data(options,project_drs)
+    #if options.command=='remote_retrieve':
+    #    paths_dict=cdb_query_archive_class.SimpleTree(options,project_drs)
+    #    getattr(paths_dict,options.command)(options)
+    #elif options.command=='download':
+    #    paths_dict=cdb_query_archive_class.SimpleTree(options,project_drs)
+    #    getattr(paths_dict,options.command)(options)
+    if options.command=='apply':
+        netcdf_utils.apply(options,project_drs)
+    elif options.command=='convert':
+        netcdf_utils.convert(options,project_drs)
     elif 'in_diagnostic_headers_file' in dir(options):
-        paths_dict=cdb_query_archive_class.SimpleTree(io_tools.open_json(options),options,project_drs)
+        paths_dict=cdb_query_archive_class.SimpleTree(options,project_drs)
         #Run the command:
         getattr(paths_dict,options.command)(options)
     elif 'in_diagnostic_netcdf_file' in dir(options):
-        paths_dict=cdb_query_archive_class.SimpleTree(io_tools.open_netcdf(options,project_drs),options,project_drs)
+        paths_dict=cdb_query_archive_class.SimpleTree(options,project_drs)
         #Run the command:
         getattr(paths_dict,options.command)(options)
         
-    #print paths_dict.pointers.tree
-    #Close the file:
-    if 'out_diagnostic_headers_file' in dir(options):
-        io_tools.close_json(paths_dict,options)
-
 if __name__ == "__main__":
     main('CMIP5')
