@@ -68,10 +68,10 @@ class nc_Database:
             output_root.setncattr(value,json.dumps(header[value]))
         return
 
-    def populate_database(self,options,find_function):
+    def populate_database(self,options,find_function,semaphores=None):
         self.load_nc_file()
         self.file_expt.time='0'
-        populate_database_recursive(self,self.Dataset,options,find_function)
+        populate_database_recursive(self,self.Dataset,options,find_function,semaphores=semaphores)
         self.close_nc_file()
         return
 
@@ -115,7 +115,8 @@ class nc_Database:
         trees_list=self.list_subset([getattr(File_Expt,level) for level in drs_list])
 
         #Create output:
-        output_root=netCDF4.Dataset(options.out_diagnostic_netcdf_file+'.pid'+str(os.getpid()),
+        filepath=options.out_diagnostic_netcdf_file+'.pid'+str(os.getpid())
+        output_root=netCDF4.Dataset(filepath,
                                       'w',format='NETCDF4',diskless=True,persist=True)
         #output_root=netCDF4.Dataset(options.out_diagnostic_netcdf_file+'.pid'+str(os.getpid()),
         #                              'w',format='NETCDF4')
@@ -151,7 +152,6 @@ class nc_Database:
 
             output=create_tree(output_root,zip(drs_list,tree))
             #Record data:
-            #print output_root.filepath(), tree
             if (time_frequency in ['fx','clim'] and record_function_handle!='record_paths'):
                 netcdf_pointers.record_fx(output,paths_list,var)
             else:
@@ -163,7 +163,7 @@ class nc_Database:
             #Remove recorded data from database:
             self.session.query(*out_tuples).filter(sqlalchemy.and_(*conditions)).delete()
 
-        return output_root
+        return output_root, filepath
 
     def retrieve_database(self,options,output,queues,retrieval_function):
         self.load_nc_file()
@@ -183,7 +183,7 @@ class nc_Database:
 #####################################################################
 #####################################################################
 
-def populate_database_recursive(nc_Database,data,options,find_function):
+def populate_database_recursive(nc_Database,data,options,find_function,semaphores=None):
     if 'soft_links' in data.groups.keys():
         soft_links=data.groups['soft_links']
         paths=soft_links.variables['path'][:]
@@ -202,13 +202,13 @@ def populate_database_recursive(nc_Database,data,options,find_function):
                                                        soft_links.variables['checksum'][path_id]]))
                 setattr(nc_Database.file_expt,'version','v'+str(soft_links.variables['version'][path_id]))
                 setattr(nc_Database.file_expt,'data_node',data_node)
-                find_function(nc_Database,copy.deepcopy(nc_Database.file_expt))
+                find_function(nc_Database,copy.deepcopy(nc_Database.file_expt),semaphores=semaphores)
     elif len(data.groups.keys())>0:
         for group in data.groups.keys():
             level_name=data.groups[group].getncattr('level_name')
             if is_level_name_included_and_not_excluded(level_name,options,group):
                 setattr(nc_Database.file_expt,data.groups[group].getncattr('level_name'),group)
-                populate_database_recursive(nc_Database,data.groups[group],options,find_function)
+                populate_database_recursive(nc_Database,data.groups[group],options,find_function,semaphores=semaphores)
     elif 'path' in data.ncattrs():
         #for fx variables:
         #id_list=['file_type','search']
@@ -338,13 +338,8 @@ def is_level_name_included_and_not_excluded(level_name,options,group):
 
 def record_to_file(output_root,output):
     netcdf_utils.replicate_netcdf_file(output_root,output)
-    netcdf_utils.replicate_full_netcdf_recursive(output_root,output,check_empty=True)
-    filepath=output.filepath()
-    output.close()
-    try:
-        os.remove(filepath)
-    except OSError:
-        pass
+    #netcdf_utils.replicate_full_netcdf_recursive(output_root,output,check_empty=True)
+    netcdf_utils.replicate_full_netcdf_recursive(output_root,output,check_empty=False)
     return
 
 class File_Expt(object):
